#pragma once

#include <eopcc/grid_structs.hpp>

namespace eopcc {

void GdalCheckRegistration();

class GDALReadError : public std::runtime_error {
public:
	GDALReadError(const char* msg) : std::runtime_error(msg) {}
};

class GDALWriteError : public std::runtime_error {
public:
	GDALWriteError(const char* msg) : std::runtime_error(msg) {}
};


// Loads a Z GridModel from a DEM file using GDAL
GridModel<float> LoadFromDEM(const std::string& dem_file_name);

// Writes a Tiff from a GridModel using GDAL
void WriteToTiff(const std::string& filename, const GridModel<float>& grid);

struct CropInfo {
	int pixel_begin;
	int pixel_end;
	int line_begin;
	int line_end;
};

struct ImageType {
	int width;
	int height;
	int bands;
	std::vector<uint16_t> data;
	bool x_backwards, y_backwards;

	ImageType () {
		x_backwards = false;
		y_backwards = false;
	}
};


// Reads a section of an NITF image into the ImageType structure
bool read_cropped_image(const char *imageFileName, ImageType &img, const CropInfo& crop_info,
						 int& min_intensity,  int& max_intensity, char *err);
bool write_jpeg_file(const char *FileName, ImageType &img, unsigned int min_intensity, unsigned int max_intensity, char *err);
bool write_tiff_file(const char *FileName, ImageType &img, char *err);


} // end namespace eopcc
